__description__ = "a module that houses routines to set up our loggers and standardize logging"
__author__ = "Reed Essick (reed.essick@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#-------------------------------------------------

import os
import logging

#-------------------------------------------------

DEFAULT_LOG_LEVEL = 10
DEFAULT_ROOTDIR = '.'
DEFAULT_LOGNAME = 'idq'

#-------------------------------------------------
### standardizing logging

def get_logpath(rootdir, logname=DEFAULT_LOGNAME):
    return os.path.join(rootdir, logname+'.log')

def get_logger(logname, log_level=DEFAULT_LOG_LEVEL, rootdir=DEFAULT_ROOTDIR, verbose=False):
    '''
    standardize how we instantiate loggers
    '''
    logger = logging.getLogger(logname)
    logger.setLevel(log_level)

    # set up FileHandler for output file
    if not os.path.exists(rootdir):
        try:
            os.makedirs(rootdir)
        except OSError: ### directory already exists
            pass
    log_path = get_logpath(rootdir, logname)
    handlers = [logging.FileHandler(log_path)]

    # set up handler for stdout
    if verbose:
        handlers.append( logging.StreamHandler() )

    # remove any existing handlers from logger to avoid repeated print statements
    for handler in logger.handlers[::-1]: ### remove in reverse order. For some reason, not all handlers are removed unless we do this
        logger.removeHandler(handler)

    # add handlers to logger
    formatter = gen_formatter()
    for handler in handlers:
        handler.setFormatter( formatter )
        logger.addHandler( handler )

    return logger

def gen_formatter():
    """
    standarizes formatting for loggers
    returns an instance of logging.Formatter
    """
    return logging.Formatter('%(asctime)s | %(name)s : %(levelname)s : %(message)s')
